Dialog Widget Tests

# Dijit.Dialog tests

## General Dialogs:

|
Introductory information spoken by screen reader if aria-describedby is added to the declaration of dialog above with value equal to the id of the container element for this text. This technique will work in Dojo 1.4.

Name: |
Location: |
Date: |
Time: |
Description: |

Dialog1 Menu
Enabled Item
Disabled Item
Cut
Copy
Paste
|
select label

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean semper sagittis velit. Cras in mi. Duis porta mauris ut ligula. Proin porta rutrum lacus. Etiam consequat scelerisque quam. Nulla facilisi. Maecenas luctus venenatis nulla. In sit amet dui non mi semper iaculis. Sed molestie tortor at ipsum. Morbi dictum rutrum magna. Sed vitae risus.

|

This is the first tab.

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean semper sagittis velit. Cras in mi. Duis porta mauris ut ligula. Proin porta rutrum lacus. Etiam consequat scelerisque quam. Nulla facilisi. Maecenas luctus venenatis nulla. In sit amet dui non mi semper iaculis. Sed molestie tortor at ipsum. Morbi dictum rutrum magna. Sed vitae risus.

This is the second tab.

Make it overflow. ipsum dolor sit amet, consectetuer adipiscing elit. Aenean semper sagittis velit. Cras in mi. Duis porta mauris ut ligula. Proin porta rutrum lacus. Etiam consequat scelerisque quam. Nulla facilisi. Maecenas luctus venenatis nulla. In sit amet dui non mi semper iaculis. Sed molestie tortor at ipsum. Morbi dictum rutrum magna. Sed vitae risus.

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean semper sagittis velit. Cras in mi. Duis porta mauris ut ligula. Proin porta rutrum lacus. Etiam consequat scelerisque quam. Nulla facilisi. Maecenas luctus venenatis nulla. In sit amet dui non mi semper iaculis. Sed molestie tortor at ipsum. Morbi dictum rutrum magna. Sed vitae risus.

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean semper sagittis velit. Cras in mi. Duis porta mauris ut ligula. Proin porta rutrum lacus. Etiam consequat scelerisque quam. Nulla facilisi. Maecenas luctus venenatis nulla. In sit amet dui non mi semper iaculis. Sed molestie tortor at ipsum. Morbi dictum rutrum magna. Sed vitae risus.

|
ID File:

You should not be able to
drag this dialog

I am done entering data:
|

The pane has some text, plus two embedded layout widgets, which should appear correctly even though the pane is initially hidden.

Here's a BorderContainer:

1Sed arcu magna, molestie at, fringilla in, sodales eu, elit. Curabitur mattis lorem et est. Quisque et tortor. Integer bibendum vulputate odio. Nam nec ipsum. Vestibulum mollis eros feugiat augue. Integer fermentum odio lobortis odio. Nullam mollis nisl non metus. Maecenas nec nunc eget pede ultrices blandit. Ut non purus ut elit convallis eleifend. Fusce tincidunt, justo quis tempus euismod, magna nulla viverra libero, sit amet lacinia odio diam id risus. Ut varius viverra turpis. Morbi urna elit, imperdiet eu, porta ac, pharetra sed, nisi. Etiam ante libero, ultrices ac, faucibus ac, cursus sodales, nisl. Praesent nisl sem, fermentum eu, consequat quis, varius interdum, nulla. Donec neque tortor, sollicitudin sed, consequat nec, facilisis sit amet, orci. Aenean ut eros sit amet ante pharetra interdum.
2Sed arcu magna, molestie at, fringilla in, sodales eu, elit. Curabitur mattis lorem et est. Quisque et tortor. Integer bibendum vulputate odio. Nam nec ipsum. Vestibulum mollis eros feugiat augue. Integer fermentum odio lobortis odio. Nullam mollis nisl non metus. Maecenas nec nunc eget pede ultrices blandit. Ut non purus ut elit convallis eleifend. Fusce tincidunt, justo quis tempus euismod, magna nulla viverra libero, sit amet lacinia odio diam id risus. Ut varius viverra turpis. Morbi urna elit, imperdiet eu, porta ac, pharetra sed, nisi. Etiam ante libero, ultrices ac, faucibus ac, cursus sodales, nisl. Praesent nisl sem, fermentum eu, consequat quis, varius interdum, nulla. Donec neque tortor, sollicitudin sed, consequat nec, facilisis sit amet, orci. Aenean ut eros sit amet ante pharetra interdum.

And a TabContainer:

1Sed arcu magna, molestie at, fringilla in, sodales eu, elit. Curabitur mattis lorem et est. Quisque et tortor. Integer bibendum vulputate odio. Nam nec ipsum. Vestibulum mollis eros feugiat augue. Integer fermentum odio lobortis odio. Nullam mollis nisl non metus. Maecenas nec nunc eget pede ultrices blandit. Ut non purus ut elit convallis eleifend. Fusce tincidunt, justo quis tempus euismod, magna nulla viverra libero, sit amet lacinia odio diam id risus. Ut varius viverra turpis. Morbi urna elit, imperdiet eu, porta ac, pharetra sed, nisi. Etiam ante libero, ultrices ac, faucibus ac, cursus sodales, nisl. Praesent nisl sem, fermentum eu, consequat quis, varius interdum, nulla. Donec neque tortor, sollicitudin sed, consequat nec, facilisis sit amet, orci. Aenean ut eros sit amet ante pharetra interdum.
2Sed arcu magna, molestie at, fringilla in, sodales eu, elit. Curabitur mattis lorem et est. Quisque et tortor. Integer bibendum vulputate odio. Nam nec ipsum. Vestibulum mollis eros feugiat augue. Integer fermentum odio lobortis odio. Nullam mollis nisl non metus. Maecenas nec nunc eget pede ultrices blandit. Ut non purus ut elit convallis eleifend. Fusce tincidunt, justo quis tempus euismod, magna nulla viverra libero, sit amet lacinia odio diam id risus. Ut varius viverra turpis. Morbi urna elit, imperdiet eu, porta ac, pharetra sed, nisi. Etiam ante libero, ultrices ac, faucibus ac, cursus sodales, nisl. Praesent nisl sem, fermentum eu, consequat quis, varius interdum, nulla. Donec neque tortor, sollicitudin sed, consequat nec, facilisis sit amet, orci. Aenean ut eros sit amet ante pharetra interdum.

Text after the widgets.

Introductory information spoken by screen reader if aria-describedby is added to the declaration of dialog above with value equal to the id of the container element for this text. This technique will work in Dojo 1.4.
Introductory information spoken by screen reader if aria-describedby is added to the declaration of dialog above with value equal to the id of the container element for this text. This technique will work in Dojo 1.4.

Name: |
Location: |
Date: |
Description: |

Best Pet Dog - Cat
Show Self-Destruct Dialog (unfocusable div)
|
|
This dialog has no close icon and the ESCAPE key won't close it. You need to use the buttons.
|

## Editor 1

first text

## Editor 2

second text

## Editor 3

third text

## Simulated Editor with Dialog:

Enter text then hit OK. Focus will be shifted to "editor" below and text will be inserted.

The button above will open a Dialog to reset the text in this textarea.

(scroll down to see more links to click, for testing positioning / scroll handling)

Here's a form. Try clicking the programatic dialog link, then focusing on the form. After the dialog closes focus should be returned to the form

plainInput
planeButton Select:

Aliquam vitae enim. Duis scelerisque metus auctor est venenatis imperdiet. Fusce dignissim porta augue. Nulla vestibulum. Integer lorem nunc, ullamcorper a, commodo ac, malesuada sed, dolor. Aenean id mi in massa bibendum suscipit. Integer eros. Nullam suscipit mauris. In pellentesque. Mauris ipsum est, pharetra semper, pharetra in, viverra quis, tellus. Etiam purus. Quisque egestas, tortor ac cursus lacinia, felis leo adipiscing nisi, et rhoncus elit dolor eget eros. Fusce ut quam. Suspendisse eleifend leo vitae ligula. Nulla facilisi. Nulla rutrum, erat vitae lacinia dictum, pede purus imperdiet lacus, ut semper velit ante id metus. Praesent massa dolor, porttitor sed, pulvinar in, consequat ut, leo. Nullam nec est. Aenean id risus blandit tortor pharetra congue. Suspendisse pulvinar.

Vestibulum convallis eros ac justo. Proin dolor. Etiam aliquam. Nam ornare elit vel augue. Suspendisse potenti. Etiam sed mauris eu neque nonummy mollis. Vestibulum vel purus ac pede semper accumsan. Vivamus lobortis, sem vitae nonummy lacinia, nisl est gravida magna, non cursus est quam sed urna. Phasellus adipiscing justo in ipsum. Duis sagittis dolor sit amet magna. Suspendisse suscipit, neque eu dictum auctor, nisi augue tincidunt arcu, non lacinia magna purus nec magna. Praesent pretium sollicitudin sapien. Suspendisse imperdiet. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos hymenaeos.

select:

Mauris pharetra lorem sit amet sapien. Nulla libero metus, tristique et, dignissim a, tempus et, metus. Ut libero. Vivamus tempus purus vel ipsum. Quisque mauris urna, vestibulum commodo, rutrum vitae, ultrices vitae, nisl. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos hymenaeos. Nulla id erat sit amet odio luctus eleifend. Proin massa libero, ultricies non, tincidunt a, vestibulum non, tellus. Nunc nunc purus, lobortis a, pulvinar at, egestas a, mi. Cras adipiscing velit a mauris. Morbi felis. Etiam at felis. Cras eget eros et justo mattis pulvinar. Nullam at justo id risus porttitor dignissim. Vestibulum sed velit vel metus tincidunt tempus. Nunc euismod nisl id dolor tristique tincidunt. Nullam placerat turpis sed odio. Curabitur in est id nibh tempus ultrices. Aliquam consectetuer dapibus eros. Aliquam nisl.

[spacer]

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean semper sagittis velit. Cras in mi. Duis porta mauris ut ligula. Proin porta rutrum lacus. Etiam consequat scelerisque quam. Nulla facilisi. Maecenas luctus venenatis nulla. In sit amet dui non mi semper iaculis. Sed molestie tortor at ipsum. Morbi dictum rutrum magna. Sed vitae risus.

Aliquam vitae enim. Duis scelerisque metus auctor est venenatis imperdiet. Fusce dignissim porta augue. Nulla vestibulum. Integer lorem nunc, ullamcorper a, commodo ac, malesuada sed, dolor. Aenean id mi in massa bibendum suscipit. Integer eros. Nullam suscipit mauris. In pellentesque. Mauris ipsum est, pharetra semper, pharetra in, viverra quis, tellus. Etiam purus. Quisque egestas, tortor ac cursus lacinia, felis leo adipiscing nisi, et rhoncus elit dolor eget eros. Fusce ut quam. Suspendisse eleifend leo vitae ligula. Nulla facilisi. Nulla rutrum, erat vitae lacinia dictum, pede purus imperdiet lacus, ut semper velit ante id metus. Praesent massa dolor, porttitor sed, pulvinar in, consequat ut, leo. Nullam nec est. Aenean id risus blandit tortor pharetra congue. Suspendisse pulvinar.

Vestibulum convallis eros ac justo. Proin dolor. Etiam aliquam. Nam ornare elit vel augue. Suspendisse potenti. Etiam sed mauris eu neque nonummy mollis. Vestibulum vel purus ac pede semper accumsan. Vivamus lobortis, sem vitae nonummy lacinia, nisl est gravida magna, non cursus est quam sed urna. Phasellus adipiscing justo in ipsum. Duis sagittis dolor sit amet magna. Suspendisse suscipit, neque eu dictum auctor, nisi augue tincidunt arcu, non lacinia magna purus nec magna. Praesent pretium sollicitudin sapien. Suspendisse imperdiet. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos hymenaeos.

select:

Mauris pharetra lorem sit amet sapien. Nulla libero metus, tristique et, dignissim a, tempus et, metus. Ut libero. Vivamus tempus purus vel ipsum. Quisque mauris urna, vestibulum commodo, rutrum vitae, ultrices vitae, nisl. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos hymenaeos. Nulla id erat sit amet odio luctus eleifend. Proin massa libero, ultricies non, tincidunt a, vestibulum non, tellus. Nunc nunc purus, lobortis a, pulvinar at, egestas a, mi. Cras adipiscing velit a mauris. Morbi felis. Etiam at felis. Cras eget eros et justo mattis pulvinar. Nullam at justo id risus porttitor dignissim. Vestibulum sed velit vel metus tincidunt tempus. Nunc euismod nisl id dolor tristique tincidunt. Nullam placerat turpis sed odio. Curabitur in est id nibh tempus ultrices. Aliquam consectetuer dapibus eros. Aliquam nisl.

| Show Dialog

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean semper sagittis velit. Cras in mi. Duis porta mauris ut ligula. Proin porta rutrum lacus. Etiam consequat scelerisque quam. Nulla facilisi. Maecenas luctus venenatis nulla. In sit amet dui non mi semper iaculis. Sed molestie tortor at ipsum. Morbi dictum rutrum magna. Sed vitae risus.

Aliquam vitae enim. Duis scelerisque metus auctor est venenatis imperdiet. Fusce dignissim porta augue. Nulla vestibulum. Integer lorem nunc, ullamcorper a, commodo ac, malesuada sed, dolor. Aenean id mi in massa bibendum suscipit. Integer eros. Nullam suscipit mauris. In pellentesque. Mauris ipsum est, pharetra semper, pharetra in, viverra quis, tellus. Etiam purus. Quisque egestas, tortor ac cursus lacinia, felis leo adipiscing nisi, et rhoncus elit dolor eget eros. Fusce ut quam. Suspendisse eleifend leo vitae ligula. Nulla facilisi. Nulla rutrum, erat vitae lacinia dictum, pede purus imperdiet lacus, ut semper velit ante id metus. Praesent massa dolor, porttitor sed, pulvinar in, consequat ut, leo. Nullam nec est. Aenean id risus blandit tortor pharetra congue. Suspendisse pulvinar.

Vestibulum convallis eros ac justo. Proin dolor. Etiam aliquam. Nam ornare elit vel augue. Suspendisse potenti. Etiam sed mauris eu neque nonummy mollis. Vestibulum vel purus ac pede semper accumsan. Vivamus lobortis, sem vitae nonummy lacinia, nisl est gravida magna, non cursus est quam sed urna. Phasellus adipiscing justo in ipsum. Duis sagittis dolor sit amet magna. Suspendisse suscipit, neque eu dictum auctor, nisi augue tincidunt arcu, non lacinia magna purus nec magna. Praesent pretium sollicitudin sapien. Suspendisse imperdiet. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos hymenaeos.

Mauris pharetra lorem sit amet sapien. Nulla libero metus, tristique et, dignissim a, tempus et, metus. Ut libero. Vivamus tempus purus vel ipsum. Quisque mauris urna, vestibulum commodo, rutrum vitae, ultrices vitae, nisl. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos hymenaeos. Nulla id erat sit amet odio luctus eleifend. Proin massa libero, ultricies non, tincidunt a, vestibulum non, tellus. Nunc nunc purus, lobortis a, pulvinar at, egestas a, mi. Cras adipiscing velit a mauris. Morbi felis. Etiam at felis. Cras eget eros et justo mattis pulvinar. Nullam at justo id risus porttitor dignissim. Vestibulum sed velit vel metus tincidunt tempus. Nunc euismod nisl id dolor tristique tincidunt. Nullam placerat turpis sed odio. Curabitur in est id nibh tempus ultrices. Aliquam consectetuer dapibus eros. Aliquam nisl.

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean semper sagittis velit. Cras in mi. Duis porta mauris ut ligula. Proin porta rutrum lacus. Etiam consequat scelerisque quam. Nulla facilisi. Maecenas luctus venenatis nulla. In sit amet dui non mi semper iaculis. Sed molestie tortor at ipsum. Morbi dictum rutrum magna. Sed vitae risus.

Aliquam vitae enim. Duis scelerisque metus auctor est venenatis imperdiet. Fusce dignissim porta augue. Nulla vestibulum. Integer lorem nunc, ullamcorper a, commodo ac, malesuada sed, dolor. Aenean id mi in massa bibendum suscipit. Integer eros. Nullam suscipit mauris. In pellentesque. Mauris ipsum est, pharetra semper, pharetra in, viverra quis, tellus. Etiam purus. Quisque egestas, tortor ac cursus lacinia, felis leo adipiscing nisi, et rhoncus elit dolor eget eros. Fusce ut quam. Suspendisse eleifend leo vitae ligula. Nulla facilisi. Nulla rutrum, erat vitae lacinia dictum, pede purus imperdiet lacus, ut semper velit ante id metus. Praesent massa dolor, porttitor sed, pulvinar in, consequat ut, leo. Nullam nec est. Aenean id risus blandit tortor pharetra congue. Suspendisse pulvinar.

Vestibulum convallis eros ac justo. Proin dolor. Etiam aliquam. Nam ornare elit vel augue. Suspendisse potenti. Etiam sed mauris eu neque nonummy mollis. Vestibulum vel purus ac pede semper accumsan. Vivamus lobortis, sem vitae nonummy lacinia, nisl est gravida magna, non cursus est quam sed urna. Phasellus adipiscing justo in ipsum. Duis sagittis dolor sit amet magna. Suspendisse suscipit, neque eu dictum auctor, nisi augue tincidunt arcu, non lacinia magna purus nec magna. Praesent pretium sollicitudin sapien. Suspendisse imperdiet. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos hymenaeos.

Mauris pharetra lorem sit amet sapien. Nulla libero metus, tristique et, dignissim a, tempus et, metus. Ut libero. Vivamus tempus purus vel ipsum. Quisque mauris urna, vestibulum commodo, rutrum vitae, ultrices vitae, nisl. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos hymenaeos. Nulla id erat sit amet odio luctus eleifend. Proin massa libero, ultricies non, tincidunt a, vestibulum non, tellus. Nunc nunc purus, lobortis a, pulvinar at, egestas a, mi. Cras adipiscing velit a mauris. Morbi felis. Etiam at felis. Cras eget eros et justo mattis pulvinar. Nullam at justo id risus porttitor dignissim. Vestibulum sed velit vel metus tincidunt tempus. Nunc euismod nisl id dolor tristique tincidunt. Nullam placerat turpis sed odio. Curabitur in est id nibh tempus ultrices. Aliquam consectetuer dapibus eros. Aliquam nisl.